package com.style24.batch.biz.dao;

import com.style24.core.support.annotation.ShopDs;

/**
 * 상품 검색 Dao
 *
 * @author eskim
 * @since 2021. 06. 06
 */
@ShopDs
public interface TsbGoodsSearchDao {

	/**
	 * 상품검색temp 삭제
	 *
	 * @author eskim
	 * @since 2021. 06. 08
	 */
	void deleteGoodsSearchTemp();

	/**
	 * 상품검색-상품기본정보 생성
	 *
	 * @author eskim
	 * @since 2021. 06. 08
	 */
	void createGoodsSearchTempByGoods(String sectionFlag);

	/**
	 * 상품검색-키워드 생성
	 *
	 * @author eskim
	 * @since 2021. 06. 08
	 */
	void updateGoodsSearchTempByKeyword();

	/**
	 * 상품검색-상품이미지 생성
	 *
	 * @author eskim
	 * @since 2021. 06. 08
	 */
	void updateGoodsSearchTempByImage(String goodsPath);

	/**
	 * 상품검색-동영상 생성
	 *
	 * @author eskim
	 * @since 2021. 06. 08
	 */
	void updateGoodsSearchTempByVideo();

	/**
	 * 상품검색-즉시적용가 생성
	 *
	 * @author eskim
	 * @since 2021. 06. 08
	 */
	void updateGoodsSearchTempByPrice();

	/**
	 * 상품검색-상품 아이콘 생성
	 *
	 * @author eskim
	 * @since 2021. 06. 08
	 */
	void updateGoodsSearchTempByIcon();

	/**
	 * 상품검색-상품 전시카테 생성
	 *
	 * @author eskim
	 * @since 2021. 06. 08
	 */
	void updateGoodsSearchTempByCate();

	/**
	 * 상품검색-자사 옵션정보 생성
	 *
	 * @author eskim
	 * @since 2021. 06. 09
	 */
	void updateGoodsSearchTempBySelfOpt();

	/**
	 * 상품검색-자사 옵션별생삭정보 생성
	 *
	 * @author eskim
	 * @since 2021. 06. 17
	 */
	void updateGoodsSearchTempBySelfColor();

	/**
	 * 상품검색 - 입점 옵션정보 생성
	 *
	 * @author eskim
	 * @since 2021. 06. 09
	 */
	void updateGoodsSearchTempBySelfNoOpt();

	/**
	 * 상품검색 - GROUP_CONCAT SESSION 변경
	 *
	 * @author eskim
	 * @since 2021. 06. 09
	 */
	void updateSessionGroupConcat();

	/**
	 * 상품검색 삭제
	 *
	 * @author eskim
	 * @since 2021. 06. 09
	 */
	void deleteGoodsSearch();

	/**
	 * 상품검색 생성 - 전체색인
	 *
	 * @author eskim
	 * @since 2021. 06. 09
	 */
	void createGoodsSearch();

	/**
	 * <!-- 상품검색 부분색인용 TEMP 상품 정보 삭제 -->
	 *
	 * @author eskim
	 * @since 2021. 06. 13
	 */
	void deleteGoodsSearchSectionTemp();

	/**
	 * 상품검색 부분색인용 상품정보 생성 - 상품추가건
	 *
	 * @author eskim
	 * @since 2021. 06. 17
	 */
	void createGoodsSearchSectionTempByGoods();

	/**
	 * 상품검색 부분색인용 상품정보 생성 - 판매가 변경건
	 *
	 * @author eskim
	 * @since 2021. 06. 13
	 */
	void saveGoodsSearchSectionTempByPrice();

	/**
	 * 상품검색 부분색인용 상품정보 생성 - 즉시할인쿠폰 변경건
	 *
	 * @author eskim
	 * @since 2021. 06. 13
	 */
	void saveGoodsSearchSectionTempByCoupon();

	/**
	 * 상품검색 부분색인용 상품정보 생성 - 타이틀 변경건
	 *
	 * @author eskim
	 * @since 2021. 06. 14
	 */
	void saveGoodsSearchSectionTempByTitle();

	/**
	 * 상품검색 부분색인용 상품정보 생성 - 혜택(딱지) 변경건
	 *
	 * @author eskim
	 * @since 2021. 06. 14
	 */
	void saveGoodsSearchSectionTempByBenefit();

	/**
	 * 상품검색 부분색인용 상품정보 생성 - 전시카테고리 변경건
	 *
	 * @author eskim
	 * @since 2021. 09. 01
	 */
	void saveGoodsSearchSectionTempByCate();

	/**
	 * 상품검색 부분색인용 상품정보 생성 - 자사 옵션정보 변경건
	 *
	 * @author eskim
	 * @since 2021. 06. 14
	 */
	void saveGoodsSearchSectionTempBySelfOpt();

	/**
	 * 상품검색 부분색인용 상품정보 생성 - 입점 옵션정보 변경건
	 *
	 * @author eskim
	 * @since 2021. 06. 14
	 */
	void saveGoodsSearchSectionTempBySelfNoOpt();

	/**
	 * 상품검색 부분색인용 상품정보 생성 - 상품상태 변경건
	 *
	 * @author eskim
	 * @since 2021. 06. 14
	 */
	void saveGoodsSearchSectionTempByStat();


	/**
	 * 상품검색 부분색인용 상품정보 생성 - 상품삭제건 생성
	 *
	 * @author eskim
	 * @since 2021. 06. 15
	 */
	void updateGoodsSearchSectionByDel();

	/**
	 * 상품검색 부분색인용 TEMP 상품 정보 삭제
	 *
	 * @author eskim
	 * @since 2021. 06. 15
	 */
	void deleteGoodsSearchSection();

	/**
	 * 상품검색 생성 - 부분색인
	 *
	 * @author eskim
	 * @since 2021. 06. 15
	 */
	void createGoodsSearchSection();

	/**
	 * 부분색인 상품정보 전체색인 에 적용 - PROC_GB: C
	 *
	 * @author eskim
	 * @since 2021. 06. 18
	 */
	void updateGoodsSearchAll();

	/**
	 * 부분색인 상품정보 전체색인 에 적용 - PROC_GB: D
	 *
	 * @author eskim
	 * @since 2021. 06. 18
	 */
	void updateGoodsSearchAllDel();

	/**
	 * 부분색인 재고수정
	 *
	 * @author jmh
	 * @since 2021. 07. 30
	 */
	void updateGoodsSearchSectionTempByStock();
}
